@@ -101,6 +101,21 @@ class ZuulTenantsLoad:
         self.tenant_resources = None
         self.gateway_url = gateway_url
         self.utests = utests
+        self.default_auth_rule_name = "__SF_DEFAULT_ADMIN"
+        self.default_auth_rule = {
+            'name': self.default_auth_rule_name,
+            'conditions': [
+                {'username': 'admin'},
+                {'roles': 'zuul_admin'}
+            ]
+        }
+        self.default_tenant_rule_name = "__SF_TENANT_ZUUL_ADMIN"
+        self.default_tenant_rule = {
+            "name": self.default_tenant_rule_name,
+            'conditions': [
+                {'roles': '{tenant.name}_zuul_admin'}
+            ]
+        }
         if self.utests:
             # Skip this for unittests
             return
@@ -189,10 +204,6 @@ class ZuulTenantsLoad:
     def merge_tenant_from_data(
             self, tenants, tenant, path, tenant_name, projects_list):
         """Load legacy zuul data object into the tenants object"""
-        if not isinstance(tenant, dict) or not tenant.get('tenant'):
-            raise RuntimeError("%s: invalid tenant block: %s" % (
-                path, tenant
-            ))
         tenant = tenant.get('tenant')
         if tenant['name'] != tenant_name:
             return
@@ -214,8 +225,16 @@ class ZuulTenantsLoad:
                 tenant_conf[name] = value
         self.sanitize_projects_list(projects_list)
 
+    def merge_auth_rule_from_data(self, auth_rules, auth_rule):
+        auth_rule = auth_rule.get('authorization-rule')
+        rule_name = auth_rule.get('name')
+        auth_rules[rule_name] = {
+            'conditions': auth_rule['conditions']
+        }
+
     def merge_tenant_from_files(
-            self, tenants, tenants_conf_files, tenant_name, projects_list):
+            self, tenants, auth_rules, tenants_conf_files,
+            tenant_name, projects_list):
         """Load legacy zuul yaml file into the tenants object"""
         self.log.debug('Merge tenant files for tenant %s' % tenant_name)
         for path in tenants_conf_files:
@@ -223,9 +242,23 @@ class ZuulTenantsLoad:
             if not data:
                 continue
             self.log.debug(" Merge tenant from data (%s)" % path)
-            for tenant in data:
-                self.merge_tenant_from_data(
-                    tenants, tenant, path, tenant_name, projects_list)
+            for data_block in data:
+                if not isinstance(data_block, dict):
+                    raise RuntimeError(
+                        "%s: invalid Zuul configuration block: %s" % (
+                            path, data_block))
+                if data_block.get('tenant'):
+                    tenant = data_block
+                    self.merge_tenant_from_data(
+                        tenants, tenant, path, tenant_name, projects_list)
+                elif data_block.get('authorization-rule'):
+                    auth_rule = data_block
+                    self.merge_auth_rule_from_data(
+                        auth_rules, auth_rule)
+                else:
+                    raise RuntimeError(
+                        "%s: invalid Zuul configuration block: %s" % (
+                            path, data_block))
 
     # Zuul configuration loading directly from resources
     def merge_tenant_from_resources(
@@ -307,19 +340,34 @@ class ZuulTenantsLoad:
         for tenant, tenant_conf in sorted(tenants.items()):
             data = {'tenant': {'name': tenant}}
             data['tenant'].update(tenant_conf)
+            # if the default admin-rules are already set, do not add them
+            admin_rules = data['tenant'].get('admin-rules', [])
+            for rule_name in [
+                self.default_auth_rule_name,
+                self.default_tenant_rule_name,
+            ]:
+                if rule_name not in admin_rules:
+                    admin_rules.append(rule_name)
+            data['tenant']['admin-rules'] = admin_rules
             final_data.append(data)
         return final_data
 
-    @staticmethod
-    def acl_to_zuul_admin_rule(acl_rule):
-        """Convert a resource ACL into a Zuul admin rule."""
-        admin_rule = {
-            'name': acl_rule['name'],
-            'conditions': [
-                {'groups': g} for g in acl_rule['groups']
-            ],
-        }
-        return admin_rule
+    def merge_auth_rules(self, auth_rules):
+        final = [
+            {'authorization-rule': self.default_auth_rule},
+            {'authorization-rule': self.default_tenant_rule},
+        ]
+        for rule_name, rule in sorted(auth_rules.items()):
+            if rule_name in [
+                self.default_auth_rule_name,
+                self.default_tenant_rule_name,
+            ]:
+                # we do not allow overriding this rule
+                continue
+            data = {'authorization-rule': {'name': rule_name}}
+            data['authorization-rule'].update(rule)
+            final.append(data)
+        return final
 
     def start(self):
         """Generate a zuul main.yaml from managesf resources and flat files"""
@@ -330,14 +378,7 @@ class ZuulTenantsLoad:
         projects_list = {}
         tenant_resources_cache = {}
 
-        # admin_rules hold the ACLs
-        gerrit_acl_rules = self.main_resources.get(
-            "resources", {}
-        ).get("acls", {}).values()
-        admin_rules = [
-            self.acl_to_zuul_admin_rule(acl_rule)
-            for acl_rule in gerrit_acl_rules
-        ]
+        auth_rules = {}
 
         for tenant_name, tenant_conf in self.main_resources.get(
                 "resources", {}).get("tenants", {}).items():
@@ -393,7 +434,8 @@ class ZuulTenantsLoad:
                 tenants_conf_files = self.discover_yaml_files(tenants_dir)
                 # And we load flat files
                 self.merge_tenant_from_files(
-                    tenants, tenants_conf_files, tenant_name, projects_list)
+                    tenants, auth_rules, tenants_conf_files,
+                    tenant_name, projects_list)
 
             # We load project from the resources
             default_conn = tenant_conf["default-connection"]
@@ -434,9 +476,8 @@ class ZuulTenantsLoad:
             self.log.debug("]-- Finish processing %s" % tenant_name)
 
         final_tenant_data = self.final_tenant_merge(tenants)
-        admin_rules_data = [
-            {'admin-rule': rule} for rule in admin_rules]
-        final_data = admin_rules_data + final_tenant_data
+        auth_rules_data = self.merge_auth_rules(auth_rules)
+        final_data = auth_rules_data + final_tenant_data
         return yaml.safe_dump(final_data)
 
 
