@@ -59,6 +59,10 @@ class ZuulTenantsLoadTests(TestCase):
         final_tenants = ztl.final_tenant_merge(final_tenants)
         expected = {
             'tenant': {
+                'admin-rules': [
+                    '__SF_DEFAULT_ADMIN',
+                    '__SF_TENANT_ZUUL_ADMIN',
+                ],
                 'name': 'local',
                 'max-nodes-per-job': 5,
                 'source': {
@@ -72,6 +76,173 @@ class ZuulTenantsLoadTests(TestCase):
         self.assertDictEqual(final_tenants[0], expected)
         self.assertEqual(len(final_tenants), 1)
 
+    def test_merge_tenant_from_flat_files_with_admin_rules(self):
+        ztl = ZuulTenantsLoad(utests=True)
+        tenants_data = """
+        - tenant:
+            name: local
+            admin-rules:
+              - rule1
+              - rule2
+            source:
+              gerrit:
+                config-projects:
+                  - common-config
+        - tenant:
+            name: local
+            max-nodes-per-job: 5
+            source:
+              gerrit:
+                untrusted-projects:
+                  - repo1
+                  - repo2
+        - authorization-rule:
+            name: rule1
+            conditions:
+              - iss: some_iss
+        - authorization-rule:
+            name: rule2
+            conditions:
+              - email: some@email.com
+        """
+        final_tenants = {}
+        final_rules = {}
+        projects_list = {}
+        tenants = yaml.safe_load(tenants_data)
+        for data in tenants:
+            if 'tenant' in data.keys():
+                ztl.merge_tenant_from_data(
+                    final_tenants, data, '/data', 'local', projects_list)
+            else:
+                ztl.merge_auth_rule_from_data(
+                    final_rules, data)
+        projects_list_expected = {'local': ['common-config', 'repo1', 'repo2']}
+        self.assertItemsEqual(
+            projects_list['local'], projects_list_expected['local'])
+        final_tenants = ztl.final_tenant_merge(final_tenants)
+        final_rules = ztl.merge_auth_rules(final_rules)
+        expected = {
+            'tenant': {
+                'name': 'local',
+                'admin-rules': [
+                    'rule1',
+                    'rule2',
+                    '__SF_DEFAULT_ADMIN',
+                    '__SF_TENANT_ZUUL_ADMIN',
+                ],
+                'max-nodes-per-job': 5,
+                'source': {
+                    'gerrit': {
+                        'config-projects': ['common-config'],
+                        'untrusted-projects': ['repo1', 'repo2']
+                        }
+                    }
+                }
+            }
+        expected_rules = [
+            {'authorization-rule': {
+                'name': 'rule1',
+                'conditions': [
+                    {'iss': 'some_iss'}
+                ]
+            }},
+            {'authorization-rule': {
+                'name': 'rule2',
+                'conditions': [
+                    {'email': 'some@email.com'}
+                ]
+            }},
+            {'authorization-rule': {
+                'name': '__SF_DEFAULT_ADMIN',
+                'conditions': [
+                    {'username': 'admin'},
+                    {'roles': 'zuul_admin'},
+                ]
+            }},
+            {'authorization-rule': {
+                'name': '__SF_TENANT_ZUUL_ADMIN',
+                'conditions': [
+                    {'roles': '{tenant.name}_zuul_admin'},
+                ]
+            }},
+        ]
+        self.assertDictEqual(final_tenants[0], expected)
+        self.assertTrue(
+            all(r in final_rules for r in expected_rules)
+        )
+
+    def test_merge_tenant_from_flat_files_cannot_override_default_rule(self):
+        ztl = ZuulTenantsLoad(utests=True)
+        tenants_data = """
+        - tenant:
+            name: local
+            source:
+              gerrit:
+                config-projects:
+                  - common-config
+        - tenant:
+            name: local
+            max-nodes-per-job: 5
+            source:
+              gerrit:
+                untrusted-projects:
+                  - repo1
+                  - repo2
+        - authorization-rule:
+            name: __SF_DEFAULT_ADMIN
+            conditions:
+              - iss: some_iss
+        """
+        final_tenants = {}
+        final_rules = {}
+        projects_list = {}
+        tenants = yaml.safe_load(tenants_data)
+        for data in tenants:
+            if 'tenant' in data.keys():
+                ztl.merge_tenant_from_data(
+                    final_tenants, data, '/data', 'local', projects_list)
+            else:
+                ztl.merge_auth_rule_from_data(
+                    final_rules, data)
+        projects_list_expected = {'local': ['common-config', 'repo1', 'repo2']}
+        self.assertItemsEqual(
+            projects_list['local'], projects_list_expected['local'])
+        final_tenants = ztl.final_tenant_merge(final_tenants)
+        final_rules = ztl.merge_auth_rules(final_rules)
+        expected = {
+            'tenant': {
+                'name': 'local',
+                'admin-rules': [
+                    '__SF_DEFAULT_ADMIN',
+                    '__SF_TENANT_ZUUL_ADMIN',
+                ],
+                'max-nodes-per-job': 5,
+                'source': {
+                    'gerrit': {
+                        'config-projects': ['common-config'],
+                        'untrusted-projects': ['repo1', 'repo2']
+                        }
+                    }
+                }
+            }
+        expected_rules = [
+            {'authorization-rule': {
+                'name': '__SF_DEFAULT_ADMIN',
+                'conditions': [
+                    {'username': 'admin'},
+                    {'roles': 'zuul_admin'},
+                ]
+            }},
+            {'authorization-rule': {
+                'name': '__SF_TENANT_ZUUL_ADMIN',
+                'conditions': [
+                    {'roles': '{tenant.name}_zuul_admin'},
+                ]
+            }},
+        ]
+        self.assertDictEqual(final_tenants[0], expected)
+        self.assertTrue(expected_rules[0] in final_rules)
+
     def test_merge_tenant_error_from_flat_files(self):
         ztl = ZuulTenantsLoad(utests=True)
         tenant_data = """
@@ -155,6 +326,10 @@ class ZuulTenantsLoadTests(TestCase):
         final_tenants = ztl.final_tenant_merge(final_tenants)
         expected_tenant_ansible_network = {
             'tenant': {
+                'admin-rules': [
+                    '__SF_DEFAULT_ADMIN',
+                    '__SF_TENANT_ZUUL_ADMIN'
+                ],
                 'max-nodes-per-job': 5,
                 'name': 'ansible-network',
                 'source': {
@@ -175,6 +350,10 @@ class ZuulTenantsLoadTests(TestCase):
         expected_tenant_local = {
             'tenant': {
                 'name': 'local',
+                'admin-rules': [
+                    '__SF_DEFAULT_ADMIN',
+                    '__SF_TENANT_ZUUL_ADMIN'
+                ],
                 'source': {
                     'gerrit': {
                         'config-projects': ['config']
@@ -186,6 +365,10 @@ class ZuulTenantsLoadTests(TestCase):
         expected_tenant_local2 = {
             'tenant': {
                 'name': 'local2',
+                'admin-rules': [
+                    '__SF_DEFAULT_ADMIN',
+                    '__SF_TENANT_ZUUL_ADMIN'
+                ],
                 'max-nodes-per-job': 5,
                 }
             }
@@ -305,62 +488,6 @@ class ZuulTenantsLoadTests(TestCase):
                 local_resources, 'gerrit')
         self.assertEqual(str(ctx.exception), "gerrit is an unknown connection")
 
-    def test_convert_acl_to_admin_rules(self):
-        ztl = ZuulTenantsLoad(utests=True)
-        resources = {
-            'config-repo': 'https://sftests.com/r/config',
-            'public-url': 'https://sftests.com/manage',
-            'resources': {
-                'tenants': {
-                    'local': {
-                        'url': 'https://sftests.com/manage',
-                        'default-connection': 'gerrit',
-                    },
-                },
-                'connections': {
-                    'gerrit': {
-                        'base-url': 'https://sftests.com/r',
-                        'type': 'gerrit'
-                    },
-                },
-                'groups': {
-                    'group1': {
-                        'description': '',
-                        'members': [
-                            'admin@sftests.com',
-                        ]
-                    },
-                    'group2': {
-                        'description': '',
-                        'members': [
-                            'admin@sftests.com',
-                        ]
-                    },
-                },
-                'acls': {
-                    'acl1': {
-                        'name': 'acl1',
-                        'file': '...',
-                        'groups': ['group1', 'group2']
-                    }
-                }
-            }
-        }
-        ztl.main_resources = resources
-        final_data = yaml.safe_load(ztl.start())
-        self.assertTrue('admin-rule' in final_data[0], final_data)
-        self.assertEqual(
-            'acl1',
-            final_data[0]['admin-rule']['name'],
-            final_data
-        )
-        self.assertTrue(
-            all(c in final_data[0]['admin-rule']['conditions']
-                for c in [{'groups': 'group1'},
-                          {'groups': 'group2'}]),
-            final_data
-        )
-
     def test_tenant_options_from_resources(self):
         tenants = {}
         ztl = ZuulTenantsLoad(utests=True)
